@@ -1,5 +1,5 @@
 package POEx::ZMQ3::Subscriber;
-$POEx::ZMQ3::Subscriber::VERSION = '0.07';
+$POEx::ZMQ3::Subscriber::VERSION = '0.071';
 use Carp;
 use POE;
 
@@ -85,7 +85,7 @@ sub zmqsock_multipart_recv {
 
 =head1 NAME
 
-POEx::ZMQ3::Subscriber - A SUB-type ZeroMQ socket
+POEx::ZMQ3::Subscriber
 
 =head1 SYNOPSIS
 
